Nek5000 core library
====================

.. note::

    The following is auto-generated using Doxygen and represents Nek5000 v17.
    The official `Nek5000 documentation`_ is hand-written and is more general.

* `Documentation produced with Doxygen <doxygen/index.html>`_

Links
-----

.. * :ref:`Upstream documentation for Nek5000 <nek:genindex>`
.. Strange intersphinx bug: WARNING: undefined label: nek:genindex (if the link has no caption the label must precede a section header)

* `Nek5000 documentation`_
* `KTH framework documentation <https://kth-nek5000.github.io/KTH_Framework>`_

.. _Nek5000 documentation: https://nek5000.github.io/NekDoc/appendix.html
